diff --git a/invenio/base/bundles.py b/invenio/base/bundles.py
index dc1ff02e5..0fa106992 100644
--- a/invenio/base/bundles.py
+++ b/invenio/base/bundles.py
@@ -1,88 +1,105 @@
 # -*- coding: utf-8 -*-
 ## This file is part of Invenio.
 ## Copyright (C) 2014 CERN.
 ##
 ## Invenio is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License as
 ## published by the Free Software Foundation; either version 2 of the
 ## License, or (at your option) any later version.
 ##
 ## Invenio is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Invenio; if not, write to the Free Software Foundation, Inc.,
 ## 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
 """Base bundles."""
 
 
 from invenio.ext.assets import Bundle
 
 
-jquery = Bundle(
-    "js/jquery.js",
-    "js/jquery.jeditable.mini.js",
-    "js/jquery.tokeninput.js",
-    "js/bootstrap.js",
-    "js/hogan.js",
-    "js/translate.js",
-    output="gen/jquery.js",
-    filters="uglifyjs",
-    name="10-jquery.js"
-)
-
 invenio = Bundle(
     "js/invenio.js",
     output="gen/invenio.js",
     filters="requirejs",
     name="90-invenio.js"
 )
 
 styles = Bundle(
     "css/token-input.css",
     "css/token-input-facebook.css",
     "less/base.less",
     "css/tags/popover.css",
     output="gen/invenio.css",
     depends=[
         "less/base.less",
         "less/base/**/*.less"
     ],
     extra={
         "rel": "stylesheet/less"
     },
     filters="less,cleancss",
     name="50-invenio.css"
 )
 
 # FIXME
 #if config.CFG_WEBSTYLE_TEMPLATE_SKIN != "default":
 #    styles.contents.append("css/" + config.CFG_WEBSTYLE_TEMPLATE_SKIN + ".css")
 
+
+jquery = Bundle(
+    "js/jquery.js",
+    "js/jquery.jeditable.mini.js",
+    "js/jquery.tokeninput.js",
+    "js/bootstrap.js",
+    "js/hogan.js",
+    "js/translate.js",
+    output="gen/jquery.js",
+    filters="uglifyjs",
+    name="10-jquery.js",
+    bower={
+        "jquery": "2.1.0",
+        "bootstrap": "3.2.0",
+        "hogan": "3.0.0",
+        "jquery.jeditable": "http://invenio-software.org/download/jquery/v1.5/js/jquery.jeditable.mini.js",
+        "jquery.tokeninput": "*"
+    }
+)
+
 # if ASSETS_DEBUG and not LESS_RUN_IN_DEBUG
 lessjs = Bundle(
     "js/less.js",
     output="gen/less.js",
     filters="uglifyjs",
-    name="00-less.js"
+    name="00-less.js",
+    bower={
+        "less": "1.7.0"
+    }
 )
 
 # if ASSETS_DEBUG and not REQUIRESJS_RUN_IN_DEBUG
 requirejs = Bundle(
     "js/require.js",
     "js/settings.js",
     output="gen/require.js",
     filters="uglifyjs",
-    name="00-require.js"
+    name="00-require.js",
+    bower={
+        "requirejs": "latest"
+    }
 )
 # else
 almondjs = Bundle(
     "js/almond.js",
     "js/settings.js",
     output="gen/almond.js",
     filters="uglifyjs",
-    name="00-require.almond.js"
+    name="00-require.almond.js",
+    bower={
+        "almond": "latest"
+    }
 )
diff --git a/invenio/ext/assets/__init__.py b/invenio/ext/assets/__init__.py
index 8f694b63e..4bad593f1 100644
--- a/invenio/ext/assets/__init__.py
+++ b/invenio/ext/assets/__init__.py
@@ -1,157 +1,181 @@
 # -*- coding: utf-8 -*-
 ## This file is part of Invenio.
 ## Copyright (C) 2012, 2013, 2014 CERN.
 ##
 ## Invenio is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License as
 ## published by the Free Software Foundation; either version 2 of the
 ## License, or (at your option) any later version.
 ##
 ## Invenio is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Invenio; if not, write to the Free Software Foundation, Inc.,
 ## 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
 """
 Additional extensions and functions for the `flask.ext.assets` module.
 
 .. py:data:: command
 
     Flask-Script command that deals with assets.
 
     Documentation is on: `webassets` :ref:`webassets:script-commands`
 
     .. code-block:: python
 
         # How to install it
         from flask.ext.script import Manager
         manager = Manager()
         manager.add_command("assets", command)
 
 .. py:data:: registry
 
     Flask-Registry registry that handles the bundles. Use it directly as it's
     lazy loaded.
 """
 
 import six
+import pkg_resources
 from webassets.bundle import is_url
-from flask import current_app
+from flask import current_app, json
 from flask.ext.assets import Environment, FlaskResolver
 
 from .extensions import BundleExtension, CollectionExtension
+from .registry import bundles
 from .wrappers import Bundle, Command
 
 
-__all__ = ("setup_app", "command", "registry", "Bundle")
+__all__ = ("bower", "bundles", "command", "setup_app", "Bundle")
 
 command = Command()
 
 
+def bower():
+    """Generate a bower.json file.
+
+    It comes with default values for the ignore. Name and version are set to
+    be invenio's.
+
+    """
+    output = {
+        "name": "invenio",
+        "version": pkg_resources.get_distribution("invenio").version,
+        "ignore": [".jshintrc", "**/*.txt"],
+        "dependencies": {},
+    }
+
+    for pkg, bundle in bundles:
+        if bundle.bower:
+            current_app.logger.info((pkg, bundle.bower))
+        output['dependencies'].update(bundle.bower)
+
+    print(json.dumps(output, indent=4))
+
+
 class InvenioResolver(FlaskResolver):
 
     """Custom resource resolver for webassets."""
 
     def resolve_source(self, ctx, item):
         """Return the absolute path of the resource.
 
         .. seealso:: :py:function:`webassets.env.Resolver:resolve_source`
         """
         if not isinstance(item, six.string_types) or is_url(item):
             return item
         if item.startswith(ctx.url):
             item = item[len(ctx.url):]
         return self.search_for_source(ctx, item)
 
     def resolve_source_to_url(self, ctx, filepath, item):
         """Return the url of the resource.
 
         Displaying them as is in debug mode as the webserver knows where to
         search for them.
 
         .. seealso::
 
             :py:function:`webassets.env.Resolver:resolve_source_to_url`
         """
         if ctx.debug:
             return item
         return super(InvenioResolver, self).resolve_source_to_url(ctx,
                                                                   filepath,
                                                                   item)
 
     def search_for_source(self, ctx, item):
         """Return absolute path of the resource.
 
         :param item: resource filename
         :return: absolute path
         .. seealso:: :py:function:`webassets.env.Resolver:search_for_source`
         """
         try:
             abspath = super(InvenioResolver, self).search_env_directory(ctx,
                                                                         item)
         except:  # FIXME do not catch all!
             # If a file is missing in production (non-debug mode), we want
             # to not break and will use /dev/null instead. The exception
             # is caught and logged.
             if not current_app.debug:
                 error = "Error loading asset file: {0}".format(item)
                 current_app.logger.exception(error)
                 abspath = "/dev/null"
             else:
                 raise
 
         return abspath
 
 Environment.resolver_class = InvenioResolver
 
 
 def setup_app(app):
     """Initialize Assets extension."""
     env = Environment(app)
     env.url = app.static_url_path + "/"
     env.directory = app.static_folder
     # The filters less and requirejs don't have the same behaviour by default.
     # Respecting that.
     app.config.setdefault("LESS_RUN_IN_DEBUG", True)
     app.config.setdefault("REQUIREJS_RUN_IN_DEBUG", False)
 
     # FIXME to be removed
     def _jinja2_new_bundle(tag, collection, name=None, filters=None):
         if len(collection):
             name = "invenio" if name is None else name
             sig = hash(",".join(collection) + "|" + str(filters))
             kwargs = {
                 "output": "{0}/{1}-{2}.{0}".format(tag, name, sig),
                 "filters": filters,
                 "extra": {"rel": "stylesheet"}
             }
 
             if tag is "css" and env.debug and \
                     not app.config.get("LESS_RUN_IN_DEBUG"):
                 kwargs["extra"]["rel"] = "stylesheet/less"
                 kwargs["filters"] = None
 
             if tag is "js" and filters and "requirejs" in filters:
                 if env.debug and \
                         not app.config.get("REQUIREJS_RUN_IN_DEBUG"):
                     # removing the filters to avoid the default "merge" filter.
                     kwargs["filters"] = None
                 else:
                     # removing the initial "/", r.js would get confused
                     # otherwise
                     collection = [c[1:] for c in collection]
 
             return Bundle(*collection, **kwargs)
 
     app.jinja_env.extend(new_bundle=_jinja2_new_bundle,
                          default_bundle_name='90-invenio')
     app.jinja_env.add_extension(BundleExtension)
     app.context_processor(BundleExtension.inject)
     # FIXME: remove me
     app.jinja_env.add_extension(CollectionExtension)
 
     return app
diff --git a/invenio/ext/script/__init__.py b/invenio/ext/script/__init__.py
index 883afdbd3..59d170608 100644
--- a/invenio/ext/script/__init__.py
+++ b/invenio/ext/script/__init__.py
@@ -1,173 +1,174 @@
 # -*- coding: utf-8 -*-
 ##
 ## This file is part of Invenio.
 ## Copyright (C) 2013, 2014 CERN.
 ##
 ## Invenio is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License as
 ## published by the Free Software Foundation; either version 2 of the
 ## License, or (at your option) any later version.
 ##
 ## Invenio is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Invenio; if not, write to the Free Software Foundation, Inc.,
 ## 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
 """Initialize and configure *Flask-Script* extension."""
 
 from __future__ import print_function
 
 import re
 import functools
 
 from flask import flash
 from flask.ext.registry import RegistryProxy, ModuleAutoDiscoveryRegistry
 from flask.ext.script import Manager as FlaskExtManager
 from functools import wraps
 from six.moves import urllib
 from werkzeug.utils import import_string, find_modules
 
 from invenio.base.signals import pre_command, post_command
 
 
 def change_command_name(method=None, new_name=None):
     """Change command name to `new_name` or replace '_' by '-'."""
     if method is None:
         return functools.partial(change_command_name, new_name=new_name)
 
     if new_name is None:
         new_name = method.__name__.replace('_', '-')
     method.__name__ = new_name
 
     return method
 
 
 def generate_secret_key():
     """Generate secret key."""
     import string
     import random
     return ''.join([random.choice(string.ascii_letters + string.digits)
                     for dummy in range(0, 256)])
 
 
 def print_progress(p, L=40, prefix='', suffix=''):
     """Print textual progress bar."""
     bricks = int(p * L)
     print('\r', prefix, end=' ')
     print('[{0}{1}] {2}%'.format('#' * bricks, ' ' * (L - bricks),
                                  int(p * 100)), end=' ')
     print(suffix, end=' ')
 
 
 def check_for_software_updates(flash_message=False):
     """Check for a new release of Invenio.
 
     :return: True if you have latest version, else False if you need to upgrade
              or None if server was not reachable.
     """
     from invenio.config import CFG_VERSION
     from invenio.base.i18n import _
     try:
         find = re.compile('Invenio v[0-9]+.[0-9]+.[0-9]+(\-rc[0-9])?'
                           ' is released')
 
         webFile = urllib.urlopen("http://invenio-software.org/repo"
                                  "/invenio/tree/RELEASE-NOTES")
 
         temp = ""
         version = ""
         version1 = ""
         while 1:
             temp = webFile.readline()
             match1 = find.match(temp)
             try:
                 version = match1.group()
                 break
             except:
                 pass
             if not temp:
                 break
 
         webFile.close()
         submatch = re.compile('[0-9]+.[0-9]+.[0-9]+(\-rc[0-9])?')
         version1 = submatch.search(version)
         web_version = version1.group().split(".")
 
         local_version = CFG_VERSION.split(".")
 
         if (web_version[0] > local_version[0] or
                 web_version[0] == local_version[0] and
                 web_version[1] > local_version[1] or
                 web_version[0] == local_version[0] and
                 web_version[1] == local_version[1] and
                 web_version[2] > local_version[2]):
             if flash_message:
                 flash(_('A newer version of Invenio is available for '
                         'download. You may want to visit %s') %
                       ('<a href=\"http://invenio-software.org/wiki'
                        '/Installation/Download\">http://invenio-software.org'
                        '/wiki/Installation/Download</a>'), 'warning')
 
             return False
     except Exception as e:
         print(e)
         if flash_message:
             flash(_('Cannot download or parse release notes from http://'
                     'invenio-software.org/repo/invenio/tree/RELEASE-NOTES'),
                   'error')
         return None
     return True
 
 
 class Manager(FlaskExtManager):
 
     """Custom manager implementation with signaling support."""
 
     def add_command(self, name, command):
         """Wrap default ``add_command`` method."""
         f = command.run
 
         @wraps(f)
         def wrapper(*args, **kwargs):
             pre_command.send(f, args=args, **kwargs)
             result = f(*args, **kwargs)
             post_command.send(f, args=args, **kwargs)
             return result
         command.run = wrapper
         return super(Manager, self).add_command(name, command)
 
 
 def register_manager(manager):
     """Register all manager plugins and default commands with the manager."""
     from six.moves.urllib.parse import urlparse
     from flask.ext.script.commands import Shell, Server, ShowUrls, Clean
     managers = RegistryProxy('managers', ModuleAutoDiscoveryRegistry, 'manage')
 
     with manager.app.app_context():
         for script in find_modules('invenio.base.scripts'):
             manager.add_command(script.split('.')[-1],
                                 import_string(script + ':manager'))
         for script in managers:
             if script.__name__ == 'invenio.base.manage':
                 continue
             manager.add_command(script.__name__.split('.')[-2],
                                 getattr(script, 'manager'))
 
     manager.add_command("clean", Clean())
     manager.add_command("show-urls", ShowUrls())
     manager.add_command("shell", Shell())
     parsed_url = urlparse(manager.app.config.get('CFG_SITE_URL'))
     port = parsed_url.port or 80
     host = parsed_url.hostname or '127.0.0.1'
     manager.add_command("runserver", Server(host=host, port=port))
 
     # FIXME separation of concerns is violated here.
     from invenio.ext.collect import collect
     collect.init_script(manager)
 
-    from invenio.ext.assets import command
+    from invenio.ext.assets import command, bower
     manager.add_command("assets", command)
+    manager.command(bower)
diff --git a/invenio/ext/assets/wrappers.py b/invenio/ext/assets/wrappers.py
index 02faf9184..615263ca5 100644
--- a/invenio/ext/assets/wrappers.py
+++ b/invenio/ext/assets/wrappers.py
@@ -1,119 +1,124 @@
 # -*- coding: utf-8 -*-
 ## This file is part of Invenio.
 ## Copyright (C) 2014 CERN.
 ##
 ## Invenio is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License as
 ## published by the Free Software Foundation; either version 2 of the
 ## License, or (at your option) any later version.
 ##
 ## Invenio is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Invenio; if not, write to the Free Software Foundation, Inc.,
 ## 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
 """Custom modified classes."""
 
 
 import os
 
 from flask import current_app
 from flask.ext.assets import Bundle as BundleBase, ManageAssets
 from flask.ext.registry import ModuleAutoDiscoveryRegistry
 from werkzeug.utils import import_string
 
 
 class Bundle(BundleBase):
 
     """
     Bundle extension with a name.
 
     The name is only used for assets ordering and requirements.
+
+    The bower dependencies are used to generate a bower.json file.
     """
 
     def __init__(self, *contents, **options):
         """
         Initialize the named bundle.
 
         :param name: name of the bundle
         :type name: str
+        :param bower: bower dependencies
+        :type bower: dict
         """
         self.name = options.pop("name", None)
+        self.bower = options.pop("bower", {})
         super(Bundle, self).__init__(*contents, **options)
 
         # ease the bundle modification
@@ -1,119 +1,124 @@
 
     """
-    Bundle extension with a name.
+    Bundle extension with a name and bower dependencies.
 
     The name is only used for assets ordering and requirements.
         self.contents = list(self.contents)
         self.app = options.pop("app", None)
         if self.name is None:
             self.name = os.path.basename(self.output)
 
 
 class BundlesAutoDiscoveryRegistry(ModuleAutoDiscoveryRegistry):
 
     """
     Registry that searches for bundles.
 
     Its registry is a list of the package name and the bundle itself. This way
     you can keep track of where a bundle was loaded from.
     """
 
     def __init__(self, module_name=None, app=None, with_setup=False,
                  silent=False):
         """
         Initialize the bundle auto discovery registry.
 
         :param module_name: where to look for bundles (default: bundles)
         :type module_name: str
 
         """
         super(BundlesAutoDiscoveryRegistry, self).__init__(
             module_name or 'bundles', app=app, with_setup=with_setup,
             silent=silent)
 
     def _discover_module(self, module):
         """Discover the bundles in the given module."""
         import_str = module + '.' + self.module_name
 
         # FIXME this boilerplate code should be factored out in Flask-Registry.
         try:
             bundles = import_string(import_str, silent=self.silent)
         except ImportError as e:
             self._handle_importerror(e, module, import_str)
         except SyntaxError as e:
             self._handle_syntaxerror(e, module, import_str)
         else:
             variables = getattr(bundles, "__all__", dir(bundles))
             for var in variables:
                 # ignore private/protected fields
                 if var.startswith('_'):
                     continue
                 bundle = getattr(bundles, var)
                 if isinstance(bundle, Bundle):
                     self.register((module, bundle))
 
 
 class Command(ManageAssets):
 
     """Command-line operation for assets."""
 
     def run(self, args):
         """Run the command-line.
 
         It loads the bundles from the :py:data:`bundles registry
         <invenio.ext.assets.registry.bundles>`.
 
         """
         if not self.env:
             self.env = current_app.jinja_env.assets_environment
 
         from .registry import bundles
         for pkg, bundle in bundles:
             current_app.logger.info("{0}: {1.name} -> {1.output}"
                                     .format(pkg, bundle))
             self.env.register(bundle.name, bundle)
 
         return super(Command, self).run(args)